@@ -275,9 +275,10 @@ const fluentConfTemplate = `{{- define "fluentConf" }}
 		@label @_LOGS_AUDIT
 	</match>
 {{- end}}
-	<match **>
-		@type stdout
-	</match>
+
+  <match **>
+    @type stdout
+  </match>
 
 </label>
 
@@ -286,7 +287,9 @@ const fluentConfTemplate = `{{- define "fluentConf" }}
 {{ . }}
 {{- end}}
 
+{{ if .PipelinesToOutputLabels }}
 # Relabel specific pipelines to multiple, outputs (e.g. ES, kafka stores)
+{{- end}}
 {{- range .PipelinesToOutputLabels }}
 {{ . }}
 {{- end}}
